@@ -3,24 +3,18 @@ Redis plugin polls Redis for stats
 
 """
 import logging
-from os import path
-import socket
-import time
 
 from newrelic_plugin_agent.plugins import base
 
 LOGGER = logging.getLogger(__name__)
 
 
-class Redis(base.Plugin):
+class Redis(base.SocketStatsPlugin):
 
     GUID = 'com.meetme.newrelic_redis_agent'
 
-    DEFAULT_HOST = 'localhost'
     DEFAULT_PORT = 6379
 
-    SOCKET_RECV_MAX = 32768
-
     def add_datapoints(self, stats):
         """Add all of the data points for a node
 
@@ -94,12 +88,7 @@ class Redis(base.Plugin):
         :rtype: socket
 
         """
-        try:
-            connection = self._connect()
-        except socket.error as error:
-            LOGGER.error('Error connecting to memcached: %s', error)
-            return None
-
+        connection = super(Redis, self).connect()
         if self.config.get('password'):
             connection.send("*2\r\n$4\r\nAUTH\r\n$%i\r\n%s\r\n" %
                             (len(self.config['password']),
@@ -109,31 +98,6 @@ class Redis(base.Plugin):
                 return connection
             LOGGER.error('Authentication error: %s', buffer_value[4:].strip())
             return None
-
-        return connection
-
-    def _connect(self):
-        """Low level interface to create a socket and connect it to the
-        memcached daemon.
-
-        :rtype: socket
-
-        """
-        if 'path' in self.config:
-            if path.exists(self.config['path']):
-                LOGGER.debug('Connecting to UNIX socket: %s',
-                             self.config['path'])
-                connection = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-                connection.connect(self.config['path'])
-            else:
-                LOGGER.error('RedisUNIX socket path does not exist: %s',
-                             self.config['path'])
-        else:
-            params = (self.config.get('host', self.DEFAULT_HOST),
-                      self.config.get('port', self.DEFAULT_PORT))
-            LOGGER.debug('Connecting to Redis at %s:%s', params[0], params[1])
-            connection = socket.socket()
-            connection.connect(params)
         return connection
 
     def fetch_data(self, connection):
@@ -143,6 +107,8 @@ class Redis(base.Plugin):
         :rtype: dict
 
         """
+        connection.send("*0\r\ninfo\r\n")
+
         # Read in the first line $1437
         buffer_value = connection.recv(self.SOCKET_RECV_MAX)
         lines = buffer_value.split('\r\n')
@@ -182,36 +148,3 @@ class Redis(base.Plugin):
                     except ValueError:
                         values[key] = value
         return values
-
-    def poll(self):
-        """This method is called after every sleep interval. If the intention
-        is to use an IOLoop instead of sleep interval based daemon, override
-        the run method.
-
-        """
-        LOGGER.info('Polling Redis')
-        start_time = time.time()
-
-        # Initialize the values each iteration
-        self.derive = dict()
-        self.gauge = dict()
-        self.rate = dict()
-        self.consumers = 0
-
-        connection = self.connect()
-        self.send_command(connection)
-        self.add_datapoints(self.fetch_data(connection))
-        connection.close()
-        del connection
-
-        # Create all of the metrics
-        LOGGER.info('Polling complete in %.2f seconds',
-                    time.time() - start_time)
-
-    def send_command(self, connection):
-        """Send the command to get the statistics from the connection.
-
-        :param socket connection: The connection
-
-        """
-        connection.send("*0\r\ninfo\r\n")
